#!/bin/bash

cd "$(dirname "$0")" || exit 1

function parseTag {
  frame_text=$(echo "$1" | grep "$2"| tr -d "[:cntrl:]")
  if [ ! -z "$frame_text" ]
  then
    frame_text=${frame_text:5}
  else
    frame_text=$3
  fi

  echo $frame_text
}

function process_file {
  filePathWithExtension=$1
  echo -n "$(tput sc)Processing $1"

  relativeFilePath=${filePathWithExtension:2}
  relativeFolderPath=$(dirname "$relativeFilePath")
  fileNameNoExtension=$(basename "$filePathWithExtension" .mp3)
  relativeFilePathNoExtension="$relativeFolderPath/$fileNameNoExtension"

  tags=$(DEBUG=0 BAIL_AFTER_TITLE=1 ./Id3TagReader.bash "$filePathWithExtension")
  trackTitle=$(parseTag "$tags" "TIT2" "None")
  album=$(parseTag "$tags" "TALB" "None")
  author=$(parseTag "$tags" "TPE1" "None")

  length=$(DEBUG=0 ./Mp3FrameHeaderReader.bash "$filePathWithExtension" 25 1 | grep "Duration" | cut -c10-)

  echo "$(tput rc)$(tput el)$relativeFilePath: ${length}s, $trackTitle, $author, $album"

  addTrackStatement="    Soundtrack.Library.AddTrack(\"$relativeFilePathNoExtension\", $length, \"$trackTitle\", \"$author\", \"$album\")"
  addTrackStatement="${addTrackStatement//\.\//}"
  addTrackStatement="${addTrackStatement//\//\\\\}"
  echo "$addTrackStatement" >> MyTracks.lua
}

echo "-- This file is automatically generated" > MyTracks.lua
echo "-- Please do not edit it" >> MyTracks.lua

currentDate=$(date)
{
  echo "SMP3_PL_VERSION = \"$currentDate\"";
  echo "function Soundtrack_LoadMyTracks()";
  echo "   if Soundtrack.Settings.MyTracksVersion == nil or Soundtrack.Settings.MyTracksVersion ~= SMP3_PL_VERSION then";
  echo "      Soundtrack.Settings.MyTracksVersion = SMP3_PL_VERSION";
  echo "      Soundtrack.Settings.MyTracksVersionSame = false";
  echo "   else";
  echo "      Soundtrack.Settings.MyTracksVersionSame = true";
  echo "   end";
} >> MyTracks.lua

FILES=$(find . -name \*.mp3)
while IFS= read -r file; do
    process_file "$file"
done <<< "$FILES"

echo "end" >> MyTracks.lua

echo "Generation complete!"

rm .hexdumptmp

